@@ -1,22 +1,15 @@
 # -*- coding: utf-8 -*-
 """
-    Cached Information
-    ~~~~~~~~~~~~~~~~~~
-
-    Classes and methods to maintain any information that is stored
+    Classes and methods to maintain any bibtex information that is stored
     outside the doctree.
 
     .. autoclass:: Cache
         :members:
 
-    .. autoclass:: BibfileCache
-        :members:
-
     .. autoclass:: BibliographyCache
         :members:
 """
 
-from collections import OrderedDict
 import ast
 import collections
 import copy
@@ -24,6 +17,10 @@ from oset import oset
 import re
 
 
+def _defaultdict_oset():
+    return collections.defaultdict(oset)
+
+
 def _raise_invalid_node(node):
     """Helper method to raise an exception when an invalid node is
     visited.
@@ -147,7 +144,7 @@ class _FilterVisitor(ast.NodeVisitor):
 
     # NameConstant is Python 3.4 only
     def visit_NameConstant(self, node):
-        return node.value
+        return node.value  # pragma: no cover
 
     # Constant is Python 3.6+ only
     # Since 3.8 Num, Str, Bytes, NameConstant and Ellipsis are just Constant
@@ -156,7 +153,7 @@ class _FilterVisitor(ast.NodeVisitor):
 
     # Not used on 3.8+
     def visit_Str(self, node):
-        return node.s
+        return node.s  # pragma: no cover
 
     def generic_visit(self, node):
         _raise_invalid_node(node)
@@ -173,7 +170,7 @@ class Cache:
     source folder) to :class:`BibfileCache` instances.
     """
 
-    _bibliographies = None
+    bibliographies = None
     """Each bibliography directive is assigned an id of the form
     bibtex-bibliography-xxx. This :class:`dict` maps each docname
     to another :class:`dict` which maps each id
@@ -184,22 +181,32 @@ class Cache:
     themselves.
     """
 
-    _cited = None
+    cited = None
     """A :class:`dict` mapping each docname to a :class:`set` of
     citation keys.
     """
 
-    _enum_count = None
+    enum_count = None
     """A :class:`dict` mapping each docname to an :class:`int`
     representing the current bibliography enumeration counter.
     """
 
-    def __init__(self):
+    foot_cited = None
+    """A :class:`dict` mapping each docname to another :class:`dict`
+    which maps each id to a :class:`set` of footnote keys.
+    """
 
+    foot_current_id = None
+    """A :class:`dict` mapping each docname to the currently active id."""
+
+    def __init__(self):
         self.bibfiles = {}
-        self._bibliographies = collections.defaultdict(dict)
-        self._cited = collections.defaultdict(oset)
-        self._enum_count = {}
+        self.bibliographies = collections.defaultdict(dict)
+        self.cited = collections.defaultdict(oset)
+        self.cited_previous = collections.defaultdict(oset)
+        self.enum_count = {}
+        self.foot_cited = collections.defaultdict(_defaultdict_oset)
+        self.foot_current_id = {}
 
     def purge(self, docname):
         """Remove  all information related to *docname*.
@@ -207,92 +214,65 @@ class Cache:
         :param docname: The document name.
         :type docname: :class:`str`
         """
-        self._bibliographies.pop(docname, None)
-        self._cited.pop(docname, None)
-        self._enum_count.pop(docname, None)
+        self.bibliographies.pop(docname, None)
+        self.cited.pop(docname, None)
+        # note: intentionally do not clear cited_previous
+        self.enum_count.pop(docname, None)
+        self.foot_cited.pop(docname, None)
+        self.foot_current_id.pop(docname, None)
 
-    def inc_enum_count(self, docname):
-        """Increment enumeration list counter for document *docname*."""
-        self._enum_count[docname] += 1
+    def merge(self, docnames, other):
+        """Merge information from *other* cache related to *docnames*.
 
-    def set_enum_count(self, docname, value):
-        """Set enumeration list counter for document *docname* to *value*."""
-        self._enum_count[docname] = value
-
-    def get_enum_count(self, docname):
-        """Get enumeration list counter for document *docname*."""
-        return self._enum_count[docname]
-
-    def add_cited(self, key, docname):
-        """Add the given *key* to the set of cited keys for
-        *docname*.
-
-        :param key: The citation key.
-        :type key: :class:`str`
-        :param docname: The document name.
-        :type docname: :class:`str`
+        :param docnames: The document names.
+        :type docnames: :class:`str`
+        :param other: The other cache.
+        :type other: :class:`Cache`
         """
-        self._cited[docname].add(key)
-
-    def get_cited_docnames(self, key):
-        """Return the *docnames* from which the given *key* is cited.
-
-        :param key: The citation key.
-        :type key: :class:`str`
-        """
-        return frozenset([
-            docname for docname, keys in self._cited.items()
-            if key in keys])
+        for docname in docnames:
+            # bibfiles and cited_previous are global, no need to merge
+            if docname in other.cited:
+                self.cited[docname] = other.cited[docname]
+            if docname in other.bibliographies:
+                self.bibliographies[docname] = other.bibliographies[docname]
+            if docname in other.enum_count:
+                self.enum_count[docname] = other.enum_count[docname]
+            self.foot_cited[docname] = other.foot_cited[docname]
+            self.foot_current_id[docname] = other.foot_current_id[docname]
 
     def get_label_from_key(self, key):
         """Return label for the given key."""
-        for bibcache in self.get_all_bibliography_caches():
-            if key in bibcache.labels:
-                return bibcache.labels[key]
+        for bibcaches in self.bibliographies.values():
+            for bibcache in bibcaches.values():
+                if key in bibcache.labels:
+                    return bibcache.labels[key]
         else:
             raise KeyError("%s not found" % key)
 
-    def get_all_cited_keys(self):
-        """Yield all citation keys, sorted first by document
-        (alphabetical), then by citation order in the document.
+    def get_all_cited_keys(self, docnames):
+        """Yield all citation keys for given *docnames* in order, then
+        ordered by citation order.
         """
-        for docname in sorted(self._cited):
-            for key in self._cited[docname]:
+        for docname in docnames:
+            for key in self.cited_previous.get(docname, []):
                 yield key
 
-    def set_bibliography_cache(self, docname, id_, bibcache):
-        """Register *bibcache* (:class:`BibliographyCache`)
-        with id *id_* for document *docname*.
-        """
-        assert id_ not in self._bibliographies[docname]
-        self._bibliographies[docname][id_] = bibcache
-
-    def get_bibliography_cache(self, docname, id_):
-        """Return :class:`BibliographyCache` with id *id_* in
-        document *docname*.
-        """
-        return self._bibliographies[docname][id_]
-
-    def get_all_bibliography_caches(self):
-        """Return all bibliography caches."""
-        for bibcaches in self._bibliographies.values():
-            for bibcache in bibcaches.values():
-                yield bibcache
-
     def _get_bibliography_entries(self, docname, id_, warn):
         """Return filtered bibliography entries, sorted by occurence
         in the bib file.
         """
         # get the information of this bibliography node
-        bibcache = self.get_bibliography_cache(docname=docname, id_=id_)
+        bibcache = self.bibliographies[docname][id_]
         # generate entries
         for bibfile in bibcache.bibfiles:
             data = self.bibfiles[bibfile].data
             for entry in data.entries.values():
                 # beware: the prefix is not stored in the data
                 # to allow reusing the data for multiple bibliographies
-                cited_docnames = self.get_cited_docnames(
-                    bibcache.keyprefix + entry.key)
+                key = bibcache.keyprefix + entry.key
+                cited_docnames = frozenset([
+                    docname for docname, keys in self.cited_previous.items()
+                    if key in keys])
                 visitor = _FilterVisitor(
                     entry=entry,
                     docname=docname,
@@ -316,10 +296,10 @@ class Cache:
                     entry.collection = data
                     yield entry2
 
-    def get_bibliography_entries(self, docname, id_, warn):
+    def get_bibliography_entries(self, docname, id_, warn, docnames):
         """Return filtered bibliography entries, sorted by citation order."""
         # get entries, ordered by bib file occurrence
-        entries = OrderedDict(
+        entries = collections.OrderedDict(
             (entry.key, entry) for entry in
             self._get_bibliography_entries(
                 docname=docname, id_=id_, warn=warn))
@@ -327,7 +307,7 @@ class Cache:
         # first, we add all keys that were cited
         # then, we add all remaining keys
         sorted_entries = []
-        for key in self.get_all_cited_keys():
+        for key in self.get_all_cited_keys(docnames):
             try:
                 entry = entries.pop(key)
             except KeyError:
@@ -337,27 +317,15 @@ class Cache:
         sorted_entries += entries.values()
         return sorted_entries
 
-
-class BibfileCache(collections.namedtuple('BibfileCache', 'mtime data')):
-
-    """Contains information about a parsed .bib file.
-
-    .. attribute:: mtime
-
-        A :class:`float` representing the modification time of the .bib
-        file when it was last parsed.
-
-    .. attribute:: data
-
-        A :class:`pybtex.database.BibliographyData` containing the
-        parsed .bib file.
-
-    """
+    def new_foot_current_id(self, env):
+        """Generate a new id for the given build environment."""
+        self.foot_current_id[env.docname] = 'bibtex-footbibliography-%s-%s' % (
+            env.docname, env.new_serialno('bibtex'))
 
 
 class BibliographyCache(collections.namedtuple(
     'BibliographyCache',
-    """bibfiles style encoding
+    """bibfiles style
 list_ enumtype start labels labelprefix
 filter_ keyprefix
 """)):
