@@ -1,7 +1,4 @@
 """
-    New Doctree Transforms
-    ~~~~~~~~~~~~~~~~~~~~~~
-
     .. autoclass:: BibliographyTransform
         :show-inheritance:
 
@@ -19,7 +16,7 @@ import sphinx.util
 
 from pybtex.plugin import find_plugin
 
-from sphinxcontrib.bibtex.nodes import bibliography
+from .nodes import bibliography
 
 
 logger = sphinx.util.logging.getLogger(__name__)
@@ -52,6 +49,15 @@ def transform_url_command(textnode):
         return textnode
 
 
+def get_docnames(env):
+    rel = env.collect_relations()
+    docname = env.config.master_doc
+    while docname is not None:
+        yield docname
+        parent, prevdoc, nextdoc = rel[docname]
+        docname = nextdoc
+
+
 class BibliographyTransform(docutils.transforms.Transform):
 
     """A docutils transform to generate citation entries for
@@ -61,7 +67,7 @@ class BibliographyTransform(docutils.transforms.Transform):
     # transform must be applied before references are resolved
     default_priority = 10
     """Priority of the transform. See
-    http://docutils.sourceforge.net/docs/ref/transforms.html
+    https://docutils.sourceforge.io/docs/ref/transforms.html
     """
 
     def apply(self):
@@ -71,12 +77,13 @@ class BibliographyTransform(docutils.transforms.Transform):
         """
         env = self.document.settings.env
         docname = env.docname
+        docnames = list(get_docnames(env))
         for bibnode in self.document.traverse(bibliography):
             id_ = bibnode['ids'][0]
-            bibcache = env.bibtex_cache.get_bibliography_cache(
-                docname=docname, id_=id_)
+            bibcache = env.bibtex_cache.bibliographies[docname][id_]
             entries = env.bibtex_cache.get_bibliography_entries(
-                docname=docname, id_=id_, warn=logger.warning)
+                docname=docname, id_=id_, warn=logger.warning,
+                docnames=docnames)
             # locate and instantiate style and backend plugins
             style = find_plugin('pybtex.style.formatting', bibcache.style)()
             backend = find_plugin('pybtex.backends', 'docutils')()
@@ -86,11 +93,9 @@ class BibliographyTransform(docutils.transforms.Transform):
                 nodes['enumtype'] = bibcache.enumtype
                 if bibcache.start >= 1:
                     nodes['start'] = bibcache.start
-                    env.bibtex_cache.set_enum_count(
-                        env.docname, bibcache.start)
+                    env.bibtex_cache.enum_count[env.docname] = bibcache.start
                 else:
-                    nodes['start'] = env.bibtex_cache.get_enum_count(
-                        env.docname)
+                    nodes['start'] = env.bibtex_cache.enum_count[env.docname]
             elif bibcache.list_ == "bullet":
                 nodes = docutils.nodes.bullet_list()
             else:  # "citation"
@@ -102,6 +107,7 @@ class BibliographyTransform(docutils.transforms.Transform):
                     citation += backend.paragraph(entry)
                 else:  # "citation"
                     citation = backend.citation(entry, self.document)
+                    citation['classes'].append('bibtex')
                     # backend.citation(...) uses entry.key as citation label
                     # we change it to entry.label later onwards
                     # but we must note the entry.label now;
@@ -111,5 +117,7 @@ class BibliographyTransform(docutils.transforms.Transform):
                 node_text_transform(citation, transform_url_command)
                 nodes += citation
                 if bibcache.list_ == "enumerated":
-                    env.bibtex_cache.inc_enum_count(env.docname)
+                    env.bibtex_cache.enum_count[env.docname] += 1
+            if env.bibtex_bibliography_header is not None:
+                nodes = [env.bibtex_bibliography_header.deepcopy(), nodes]
             bibnode.replace_self(nodes)
