@@ -6,19 +6,12 @@
     Bib file not found check.
 """
 
+import pytest
 import re
-from sphinx_testing.util import path, with_app
 
 
-srcdir = path(__file__).dirname().joinpath('bibfilenotfound').abspath()
-
-
-def teardown_module():
-    (srcdir / '_build').rmtree(True)
-
-
-@with_app(srcdir=srcdir)
-def test_bibfilenotfound(app, status, warning):
+@pytest.mark.sphinx('html', testroot='bibfilenotfound')
+def test_bibfilenotfound(app, warning):
     app.builder.build_all()
     assert re.search(
         'could not open bibtex file .*unknown[.]bib', warning.getvalue())
