@@ -7,60 +7,54 @@
 """
 
 import re
-from sphinx_testing.util import path, with_app
+import pytest
 
 
-srcdir = path(__file__).dirname().joinpath('filter').abspath()
-
-
-def teardown_module():
-    (srcdir / '_build').rmtree(True)
-
-
-@with_app(srcdir=srcdir, warningiserror=True)
-def test_filter(app, status, warning):
+@pytest.mark.sphinx('html', testroot='filter')
+def test_filter(app, warning):
     app.builder.build_all()
-    output = (path(app.outdir) / "index.html").read_text(encoding='utf-8')
+    assert not warning.getvalue()
+    output = (app.outdir / "index.html").read_text(encoding='utf-8')
     assert re.search('Tralalala', output)
     assert not re.search('ideetje', output)
     assert not re.search('Jakkamakka', output)
-    output = (path(app.outdir) / "or.html").read_text(encoding='utf-8')
+    output = (app.outdir / "or.html").read_text(encoding='utf-8')
     assert not re.search('Tralalala', output)
     assert re.search('ideetje', output)
     assert re.search('Jakkamakka', output)
-    output = (path(app.outdir) / "noteq.html").read_text(encoding='utf-8')
+    output = (app.outdir / "noteq.html").read_text(encoding='utf-8')
     assert re.search('Tralalala', output)
     assert re.search('ideetje', output)
     assert not re.search('Jakkamakka', output)
-    output = (path(app.outdir) / "lt.html").read_text(encoding='utf-8')
+    output = (app.outdir / "lt.html").read_text(encoding='utf-8')
     assert re.search('Tralalala', output)
     assert not re.search('ideetje', output)
     assert not re.search('Jakkamakka', output)
-    output = (path(app.outdir) / "lte.html").read_text(encoding='utf-8')
+    output = (app.outdir / "lte.html").read_text(encoding='utf-8')
     assert re.search('Tralalala', output)
     assert not re.search('ideetje', output)
     assert re.search('Jakkamakka', output)
-    output = (path(app.outdir) / "gt.html").read_text(encoding='utf-8')
+    output = (app.outdir / "gt.html").read_text(encoding='utf-8')
     assert not re.search('Tralalala', output)
     assert re.search('ideetje', output)
     assert not re.search('Jakkamakka', output)
-    output = (path(app.outdir) / "gte.html").read_text(encoding='utf-8')
+    output = (app.outdir / "gte.html").read_text(encoding='utf-8')
     assert not re.search('Tralalala', output)
     assert re.search('ideetje', output)
     assert re.search('Jakkamakka', output)
-    output = (path(app.outdir) / "key.html").read_text(encoding='utf-8')
+    output = (app.outdir / "key.html").read_text(encoding='utf-8')
     assert not re.search('Tralalala', output)
     assert re.search('ideetje', output)
     assert not re.search('Jakkamakka', output)
-    output = (path(app.outdir) / "false.html").read_text(encoding='utf-8')
+    output = (app.outdir / "false.html").read_text(encoding='utf-8')
     assert not re.search('Tralalala', output)
     assert not re.search('ideetje', output)
     assert not re.search('Jakkamakka', output)
-    output = (path(app.outdir) / "true.html").read_text(encoding='utf-8')
+    output = (app.outdir / "true.html").read_text(encoding='utf-8')
     assert re.search('Tralalala', output)
     assert re.search('ideetje', output)
     assert re.search('Jakkamakka', output)
-    output = (path(app.outdir) / "title.html").read_text(encoding='utf-8')
+    output = (app.outdir / "title.html").read_text(encoding='utf-8')
     assert not re.search('Tralalala', output)
     assert not re.search('ideetje', output)
     assert re.search('Jakkamakka', output)
