@@ -6,20 +6,15 @@
     Test multiple keys in a single cite.
 """
 
+import pytest
 import re
-from sphinx_testing.util import path, with_app
-
-srcdir = path(__file__).dirname().joinpath('issue61').abspath()
 
 
-def teardown_module():
-    (srcdir / '_build').rmtree(True)
-
-
-@with_app(srcdir=srcdir, warningiserror=True)
-def test_multiple_keys(app, status, warning):
+@pytest.mark.sphinx('html', testroot='issue61')
+def test_multiple_keys(app, warning):
     app.builder.build_all()
-    output = (path(app.outdir) / "index.html").read_text(encoding='utf-8')
+    assert not warning.getvalue()
+    output = (app.outdir / "index.html").read_text(encoding='utf-8')
     assert re.search(
         'class="bibtex reference internal" href="#testone"', output)
     assert re.search(
