@@ -6,19 +6,12 @@
     Test invalid ``:list:`` option.
 """
 
+import pytest
 import re
-from sphinx_testing.util import path, with_app
 
 
-srcdir = path(__file__).dirname().joinpath('list_invalid').abspath()
-
-
-def teardown_module():
-    (srcdir / '_build').rmtree(True)
-
-
-@with_app(srcdir=srcdir)
-def test_list_invalid(app, status, warning):
+@pytest.mark.sphinx('html', testroot='list_invalid')
+def test_list_invalid(app, warning):
     app.builder.build_all()
     assert re.search(
         "unknown bibliography list type 'thisisintentionallyinvalid'",
